summaryrefslogtreecommitdiff
path: root/nuttx/arch/x86/src/qemu/qemu_vectors.S
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/arch/x86/src/qemu/qemu_vectors.S')
-rwxr-xr-xnuttx/arch/x86/src/qemu/qemu_vectors.S6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/arch/x86/src/qemu/qemu_vectors.S b/nuttx/arch/x86/src/qemu/qemu_vectors.S
index a512e1f95..87412c21b 100755
--- a/nuttx/arch/x86/src/qemu/qemu_vectors.S
+++ b/nuttx/arch/x86/src/qemu/qemu_vectors.S
@@ -86,7 +86,7 @@ vector_isr\intno:
cli /* Disable interrupts firstly. */
push $0 /* Push a dummy error code. */
push $\intno /* Push the interrupt number. */
- jmp isr_common /* Go to the common handler code. */
+ jmp isr_common /* Go to the common ISR handler code. */
.endm
/* This macro creates a stub for an ISR which passes it's own
@@ -98,7 +98,7 @@ vector_isr\intno:
vector_isr\intno:
cli /* Disable interrupts firstly. */
push $\intno /* Push the interrupt number. */
- jmp isr_common /* Go to the common handler code. */
+ jmp isr_common /* Go to the common ISR handler code. */
.endm
/* This macro creates a stub for an IRQ - the first parameter is
@@ -111,7 +111,7 @@ vector_irq\irqno:
cli /* Disable interrupts firstly. */
push $0 /* Push a dummy error code. */
push $\intno /* Push the interrupt number. */
- jmp isr_common /* Go to the common handler code. */
+ jmp irq_common /* Go to the common IRQ handler code. */
.endm
/****************************************************************************